@@ -19,7 +19,7 @@ our $EPANSI_OTHER_COLOR = 'cyan';
 our $EPANSI_SCRIPT_COLOR = 'yellow';
 our $EPANSI_SUB_COLOR = 'green';
 
-our $VERSION = 0.01;
+our $VERSION = 0.02;
 
 # Pretty print of backtrace.
 sub err_bt_pretty {
@@ -58,7 +58,6 @@ sub err_die {
 		color($EPANSI_LINE_COLOR)."$stack_ar->[0]->{'line'}.".
 		color('reset');
 	return $die;
-		die "$die\n";
 }
 
 # Pretty print line error.
@@ -89,7 +88,7 @@ sub err_print_var {
 	my @errors = @_;
 	my @msg = @{$errors[-1]->{'msg'}};
 	my $class = _err_class($errors[-1]);
-	my @ret = ($class.(shift @msg));
+	my @ret = ($class.color($EPANSI_ERROR_COLOR).(shift @msg).color('reset'));
 	push @ret, _err_variables(@msg);
 	return wantarray ? @ret : (join "\n", @ret)."\n";
 }
@@ -707,6 +706,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.01
+0.02
 
 =cut
